=======
History
=======

0.1.2 (2018-09-17)
------------------

* Added requirements file.
* Fixed tox configuration for CI.
* Fixed readthedocs configuration.

0.1.0 (2018-09-17)
------------------

* First release on PyPI.
